@@ -53,8 +53,9 @@ use crate::Token::*;
 #[derive(Clone,PartialEq,Debug)]
 pub enum Token
 {
-   /// non-negative base-10 integers.
-   /// Negative signs are emitted as separate symbols
+   /// non-negative base-10 integers.  It is however, more convenient to
+   /// capture the value as a signed integer despite the fact that
+   /// negative signs are emitted as separate symbols.
    Integer(i64), /// non-negative base-10 floating-point numbers
    Float(f64),
    /// non-alphanumeric symbols such as "==".  Note that a substring such as
@@ -195,7 +196,7 @@ fn match_symbol(s:&str) -> usize
    while !stop && index<s.len()
    {
      c = chars.next().unwrap();
-     if !c.is_whitespace() && !c.is_ascii_digit() && !c.is_alphanumeric() && c!='_' && c!='\"' && c!='.'
+     if !c.is_whitespace() && !c.is_ascii_digit() && !c.is_alphanumeric() && c!='_' && c!='\"' && c!='.' && !isdelim(c)
      {index+=1;} else {stop=true;}
    }
    return index;
@@ -507,7 +508,7 @@ fn match_symbol(&mut self, s:&str) -> usize
    while !stop && index<s.len()
    {
      c = chars.next().unwrap();
-     if !c.is_whitespace() && !c.is_ascii_digit() && !c.is_alphanumeric() && c!='_' && c!='\"' && c!='.'
+     if !c.is_whitespace() && !c.is_ascii_digit() && !c.is_alphanumeric() && c!='_' && c!='\"' && c!='.' && !self.singletons.contains(&c)
      {index+=1;} else {stop=true;}
    }
    return index;
